from django.contrib.auth import get_user_model

from rest_framework.test import APITestCase

from event.models import Event, Place, ActivityTag, ActivityTemplate

from api.event.serializers import ActivityTemplateSerializer,\
        EventSerializer, Activity
from api.test_mixins import EventBasedModelTestMixin, EventSpecificTestMixin,\
        ModelTestMixin

User = get_user_model()


class EventTests(ModelTestMixin, APITestCase):
    model = Event
    base_name = 'event'
    tested_fields = {'title': "I'm a test", }
    # Création
    data_creation = 'event2_data'
    # Update/Delete
    instance_name = 'event1'
    serializer = EventSerializer


class ActivityTemplateTests(EventBasedModelTestMixin, APITestCase):
    model = ActivityTemplate
    base_name = 'event-activitytemplate'
    # Creation
    data_creation = 'act_temp2_data'
    # Update/Delete
    instance_name = 'act_temp1'
    field_tested = 'title'
    serializer = ActivityTemplateSerializer

    def test_create_extra(self):
        self.assertEqual(self.model.objects.get(id=1).tags.count(), 1)

    def pre_update_extra(self, data):
        data['tags'].append(self.tag2_data)
        return data

    def post_update_extra(self, instance):
        self.assertEqual(instance.tags.count(), 2)


class ActivityTests(EventBasedModelTestMixin, APITestCase):
    model = Activity
    base_name = 'event-activity'
    # Creation
    data_creation = 'act2_data'
    # Update/Delete
    instance_name = 'act1'
    field_tested = 'title'
    serializer = ActivityTemplateSerializer

    def test_create_extra(self):
        self.assertEqual(self.model.objects.get(id=1).tags.count(), 1)

    def pre_update_extra(self, data):
        data['tags'].append(self.tag2_data)
        return data

    def post_update_extra(self, instance):
        self.assertEqual(instance.tags.count(), 2)


class EventSpecficTagTests(EventSpecificTestMixin, APITestCase):
    model = ActivityTag
    root_base_name = 'activitytag'
    event_base_name = 'event-activitytag'


class EventSpecficPlaceTests(EventSpecificTestMixin, APITestCase):
    model = Place
    root_base_name = 'place'
    event_base_name = 'event-place'
